ImageCompressor class

Constructors

ImageCompressor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compressImagesInParallel(Uint8List inputData, int maxSizeInBytes) Future<Uint8List>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compress(dynamic data) Future<Uint8List?>
compress can used in compute function PASS DATA AS LIST First parameter always the input of Uint8List Second parameter is size in bytes (MaxSizeInBytes)int If anyone value is missing then compress will emit null