ScreenShotModel class
Constructors
- ScreenShotModel.name(Uint8List? imageByte, ActiveWindowInfo? windowInfo, String? base64Image)
Properties
- base64Image ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageByte ↔ Uint8List?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- windowInfo ↔ ActiveWindowInfo?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited